pub struct CrlDistributionPoints(pub Vec<DistributionPoint>);Expand description
CrlDistributionPoints as defined in RFC 5280 Section 4.2.1.13.
CRLDistributionPoints ::= SEQUENCE SIZE (1..MAX) OF DistributionPointTuple Fields
0: Vec<DistributionPoint>Trait Implementations
Sourceimpl<'a> AsMut<Vec<DistributionPoint>> for CrlDistributionPoints
impl<'a> AsMut<Vec<DistributionPoint>> for CrlDistributionPoints
Sourcefn as_mut(&mut self) -> &mut Vec<DistributionPoint>
fn as_mut(&mut self) -> &mut Vec<DistributionPoint>
Converts this type into a mutable reference of the (usually inferred) input type.
Sourceimpl<'a> AsRef<Vec<DistributionPoint>> for CrlDistributionPoints
impl<'a> AsRef<Vec<DistributionPoint>> for CrlDistributionPoints
Sourcefn as_ref(&self) -> &Vec<DistributionPoint>
fn as_ref(&self) -> &Vec<DistributionPoint>
Converts this type into a shared reference of the (usually inferred) input type.
Sourceimpl AssociatedOid for CrlDistributionPoints
impl AssociatedOid for CrlDistributionPoints
Sourceconst OID: ObjectIdentifier = ID_CE_CRL_DISTRIBUTION_POINTS
const OID: ObjectIdentifier = ID_CE_CRL_DISTRIBUTION_POINTS
The OID associated with this type.
Sourceimpl Clone for CrlDistributionPoints
impl Clone for CrlDistributionPoints
Sourceimpl Criticality for CrlDistributionPoints
impl Criticality for CrlDistributionPoints
Sourceimpl Debug for CrlDistributionPoints
impl Debug for CrlDistributionPoints
Sourceimpl<'a> DecodeValue<'a> for CrlDistributionPoints
impl<'a> DecodeValue<'a> for CrlDistributionPoints
Sourceimpl Default for CrlDistributionPoints
impl Default for CrlDistributionPoints
Sourceimpl<'a> EncodeValue for CrlDistributionPoints
impl<'a> EncodeValue for CrlDistributionPoints
impl Eq for CrlDistributionPoints
Sourceimpl<'a> FixedTag for CrlDistributionPoints
impl<'a> FixedTag for CrlDistributionPoints
Sourceimpl<'a> From<CrlDistributionPoints> for Vec<DistributionPoint>
impl<'a> From<CrlDistributionPoints> for Vec<DistributionPoint>
Sourcefn from(value: CrlDistributionPoints) -> Self
fn from(value: CrlDistributionPoints) -> Self
Converts to this type from the input type.
Sourceimpl<'a> From<Vec<DistributionPoint>> for CrlDistributionPoints
impl<'a> From<Vec<DistributionPoint>> for CrlDistributionPoints
Sourcefn from(value: Vec<DistributionPoint>) -> Self
fn from(value: Vec<DistributionPoint>) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for CrlDistributionPoints
impl PartialEq for CrlDistributionPoints
impl StructuralPartialEq for CrlDistributionPoints