pub struct FreshestCrl(pub Vec<DistributionPoint>);Expand description
FreshestCrl as defined in RFC 5280 Section 5.2.6.
FreshestCRL ::= CRLDistributionPointsTuple Fields
0: Vec<DistributionPoint>Trait Implementations
Sourceimpl<'a> AsMut<Vec<DistributionPoint>> for FreshestCrl
impl<'a> AsMut<Vec<DistributionPoint>> for FreshestCrl
Sourcefn as_mut(&mut self) -> &mut Vec<DistributionPoint>
fn as_mut(&mut self) -> &mut Vec<DistributionPoint>
Converts this type into a mutable reference of the (usually inferred) input type.
Sourceimpl<'a> AsRef<Vec<DistributionPoint>> for FreshestCrl
impl<'a> AsRef<Vec<DistributionPoint>> for FreshestCrl
Sourcefn as_ref(&self) -> &Vec<DistributionPoint>
fn as_ref(&self) -> &Vec<DistributionPoint>
Converts this type into a shared reference of the (usually inferred) input type.
Sourceimpl AssociatedOid for FreshestCrl
impl AssociatedOid for FreshestCrl
Sourceconst OID: ObjectIdentifier = ID_CE_FRESHEST_CRL
const OID: ObjectIdentifier = ID_CE_FRESHEST_CRL
The OID associated with this type.
Sourceimpl Clone for FreshestCrl
impl Clone for FreshestCrl
Sourceimpl Criticality for FreshestCrl
impl Criticality for FreshestCrl
Sourceimpl Debug for FreshestCrl
impl Debug for FreshestCrl
Sourceimpl<'a> DecodeValue<'a> for FreshestCrl
impl<'a> DecodeValue<'a> for FreshestCrl
Sourceimpl Default for FreshestCrl
impl Default for FreshestCrl
Sourceimpl<'a> EncodeValue for FreshestCrl
impl<'a> EncodeValue for FreshestCrl
impl Eq for FreshestCrl
Sourceimpl<'a> FixedTag for FreshestCrl
impl<'a> FixedTag for FreshestCrl
Sourceimpl<'a> From<FreshestCrl> for Vec<DistributionPoint>
impl<'a> From<FreshestCrl> for Vec<DistributionPoint>
Sourcefn from(value: FreshestCrl) -> Self
fn from(value: FreshestCrl) -> Self
Converts to this type from the input type.
Sourceimpl<'a> From<Vec<DistributionPoint>> for FreshestCrl
impl<'a> From<Vec<DistributionPoint>> for FreshestCrl
Sourcefn from(value: Vec<DistributionPoint>) -> Self
fn from(value: Vec<DistributionPoint>) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for FreshestCrl
impl PartialEq for FreshestCrl
impl StructuralPartialEq for FreshestCrl